@@ -1,7 +1,8 @@
 import logging
 from time import sleep
 from credstuffer.proxy import Proxy
-from credstuffer.exceptions import ProxyMaxRequestError, ProxyBadConnectionError, InternetConnectionError
+from credstuffer.exceptions import ProxyMaxRequestError, ProxyNotSetError, ProxyBadConnectionError, \
+    InternetConnectionError
 
 
 class Stuffer:
@@ -29,10 +30,13 @@ class Stuffer:
         while not proxy_alive:
             proxy = self.__get_proxy_dict()
             if self.account.is_proxy_alive(proxy=proxy):
-                self.account.set_proxy(proxy=proxy)
-                # proxy was renewed therefore the user agent shall be renewed as well
-                self.account.set_random_user_agent()
-                proxy_alive = True
+                try:
+                    self.account.set_proxy(proxy=proxy)
+                    # proxy was renewed therefore the user agent shall be renewed as well
+                    self.account.set_random_user_agent()
+                    proxy_alive = True
+                except TypeError as ex:
+                    self.logger.error(ex)
 
     def account_login(self, password):
         """ executes the account login with given password
@@ -40,14 +44,18 @@ class Stuffer:
         """
         try:
             self.account.login(password)
-        except (ProxyMaxRequestError, ProxyBadConnectionError) as ex:
-            self.logger.error("ProxyError: {}".format(ex))
+        except (ProxyMaxRequestError, ProxyBadConnectionError, ProxyNotSetError) as ex:
+            self.logger.error("{}".format(ex))
             self.set_account_proxy()
             self.account_login(password=password)
         except InternetConnectionError as ex:
-            self.logger.error("No Internet Connection: {}".format(ex))
+            self.logger.error("{}".format(ex))
             sleep(10)
             self.account_login(password=password)
+        except Exception as ex:
+            self.logger.error("FATAL ERROR: {}".format(ex))
+            self.set_account_proxy()
+            self.account_login(password=password)
 
     def __get_proxy_dict(self):
         """ get proxy dictionary
